summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRajeev Kumar <rajekuma@codeaurora.org>2016-04-15 15:18:42 -0700
committerGerrit - the friendly Code Review server <code-review@localhost>2016-04-20 22:20:32 -0700
commitc9a50e769f4d672723bc200cfbe653e80d34c2f5 (patch)
tree025ccb9cd88708277f7d95fff13d658fb8c4d542
parentcf835a082bb07b6a6dc616064ea7f8b157288013 (diff)
qcacld-3.0: (part-4) Remove obsoleted BTAMP feature
Remove all the code written to support this feature as this feature has been obsoleted for all next gen projects. Change-Id: I469841f719ddb43710724013e4b669560f0a008b CRs-Fixed: 992930
-rw-r--r--core/mac/src/pe/lim/lim_process_sme_req_messages.c64
-rw-r--r--core/mac/src/pe/sch/sch_beacon_gen.c2
-rw-r--r--core/mac/src/pe/sch/sch_beacon_process.c24
-rw-r--r--core/sme/src/csr/csr_api_roam.c5
-rw-r--r--core/wma/src/wma_data.c3
5 files changed, 27 insertions, 71 deletions
diff --git a/core/mac/src/pe/lim/lim_process_sme_req_messages.c b/core/mac/src/pe/lim/lim_process_sme_req_messages.c
index a1833859c6a1..026a50a89c0e 100644
--- a/core/mac/src/pe/lim/lim_process_sme_req_messages.c
+++ b/core/mac/src/pe/lim/lim_process_sme_req_messages.c
@@ -367,17 +367,11 @@ __lim_fresh_scan_reqd(tpAniSirGlobal mac_ctx, uint8_t return_fresh_results)
mac_ctx->lim.gpSession[i].limSmeState);
if (mac_ctx->lim.gpSession[i].valid == true) {
if (!((((mac_ctx->lim.gpSession[i].bssType ==
- eSIR_INFRASTRUCTURE_MODE) ||
- (mac_ctx->lim.gpSession[i].limSystemRole ==
- eLIM_BT_AMP_STA_ROLE)) &&
+ eSIR_INFRASTRUCTURE_MODE)) &&
(mac_ctx->lim.gpSession[i].limSmeState ==
eLIM_SME_LINK_EST_STATE)) ||
(((mac_ctx->lim.gpSession[i].bssType ==
- eSIR_IBSS_MODE) ||
- (mac_ctx->lim.gpSession[i].limSystemRole ==
- eLIM_BT_AMP_AP_ROLE) ||
- (mac_ctx->lim.gpSession[i].limSystemRole ==
- eLIM_BT_AMP_STA_ROLE)) &&
+ eSIR_IBSS_MODE)) &&
(mac_ctx->lim.gpSession[i].limSmeState ==
eLIM_SME_NORMAL_STATE)) ||
((((mac_ctx->lim.gpSession[i].bssType ==
@@ -828,14 +822,6 @@ __lim_handle_sme_start_bss_request(tpAniSirGlobal mac_ctx, uint32_t *msg_buf)
break;
- case eSIR_BTAMP_AP_MODE:
- session->limSystemRole = eLIM_BT_AMP_AP_ROLE;
- break;
-
- case eSIR_BTAMP_STA_MODE:
- session->limSystemRole = eLIM_BT_AMP_STA_ROLE;
- break;
-
/*
* There is one more mode called auto mode.
* which is used no where
@@ -849,23 +835,22 @@ __lim_handle_sme_start_bss_request(tpAniSirGlobal mac_ctx, uint32_t *msg_buf)
}
/*
- * BT-AMP: Allocate memory for the array of
+ * Allocate memory for the array of
* parsed (Re)Assoc request structure
*/
- if ((sme_start_bss_req->bssType == eSIR_BTAMP_AP_MODE) ||
- (sme_start_bss_req->bssType == eSIR_INFRA_AP_MODE)) {
+ if (sme_start_bss_req->bssType == eSIR_INFRA_AP_MODE) {
session->parsedAssocReq =
qdf_mem_malloc(session->dph.dphHashTable.
- size * sizeof(tpSirAssocReq));
+ size * sizeof(tpSirAssocReq));
if (NULL == session->parsedAssocReq) {
lim_log(mac_ctx, LOGW,
- FL("AllocateMemory() failed"));
+ FL("AllocateMemory() failed"));
ret_code = eSIR_SME_RESOURCES_UNAVAILABLE;
goto free;
}
qdf_mem_set(session->parsedAssocReq,
- (session->dph.dphHashTable.size *
- sizeof(tpSirAssocReq)), 0);
+ (session->dph.dphHashTable.size *
+ sizeof(tpSirAssocReq)), 0);
}
if (!sme_start_bss_req->channelId) {
@@ -969,9 +954,7 @@ __lim_handle_sme_start_bss_request(tpAniSirGlobal mac_ctx, uint32_t *msg_buf)
/* Fill PE session Id from the session Table */
mlm_start_req->sessionId = session->peSessionId;
- if ((mlm_start_req->bssType == eSIR_BTAMP_STA_MODE) ||
- (mlm_start_req->bssType == eSIR_BTAMP_AP_MODE) ||
- (mlm_start_req->bssType == eSIR_INFRA_AP_MODE)) {
+ if (mlm_start_req->bssType == eSIR_INFRA_AP_MODE) {
/*
* Copy the BSSId from sessionTable to
* mlmStartReq struct
@@ -1872,8 +1855,6 @@ __lim_process_sme_join_req(tpAniSirGlobal mac_ctx, uint32_t *msg_buf)
if (session->bssType == eSIR_INFRASTRUCTURE_MODE) {
session->limSystemRole = eLIM_STA_ROLE;
- } else if (session->bssType == eSIR_BTAMP_AP_MODE) {
- session->limSystemRole = eLIM_BT_AMP_STA_ROLE;
} else {
/*
* Throw an error and return and make
@@ -2473,7 +2454,6 @@ static void __lim_process_sme_disassoc_req(tpAniSirGlobal pMac, uint32_t *pMsgBu
switch (GET_LIM_SYSTEM_ROLE(psessionEntry)) {
case eLIM_STA_ROLE:
- case eLIM_BT_AMP_STA_ROLE:
switch (psessionEntry->limSmeState) {
case eLIM_SME_ASSOCIATED_STATE:
case eLIM_SME_LINK_EST_STATE:
@@ -2559,7 +2539,6 @@ static void __lim_process_sme_disassoc_req(tpAniSirGlobal pMac, uint32_t *pMsgBu
break;
case eLIM_AP_ROLE:
- case eLIM_BT_AMP_AP_ROLE:
/* Fall through */
break;
@@ -2676,7 +2655,6 @@ static void __lim_process_sme_disassoc_cnf(tpAniSirGlobal pMac, uint32_t *pMsgBu
switch (GET_LIM_SYSTEM_ROLE(psessionEntry)) {
case eLIM_STA_ROLE:
- case eLIM_BT_AMP_STA_ROLE: /* To test reconn */
if ((psessionEntry->limSmeState != eLIM_SME_IDLE_STATE) &&
(psessionEntry->limSmeState != eLIM_SME_WT_DISASSOC_STATE)
&& (psessionEntry->limSmeState !=
@@ -2811,8 +2789,6 @@ static void __lim_process_sme_deauth_req(tpAniSirGlobal mac_ctx,
switch (GET_LIM_SYSTEM_ROLE(session_entry)) {
case eLIM_STA_ROLE:
- case eLIM_BT_AMP_STA_ROLE:
-
switch (session_entry->limSmeState) {
case eLIM_SME_ASSOCIATED_STATE:
case eLIM_SME_LINK_EST_STATE:
@@ -3023,12 +2999,10 @@ __lim_process_sme_set_context_req(tpAniSirGlobal mac_ctx, uint32_t *msg_buf)
session_entry, 0, 0);
#endif /* FEATURE_WLAN_DIAG_SUPPORT */
- if (((LIM_IS_STA_ROLE(session_entry) ||
- LIM_IS_BT_AMP_STA_ROLE(session_entry)) &&
+ if ((LIM_IS_STA_ROLE(session_entry) &&
(session_entry->limSmeState == eLIM_SME_LINK_EST_STATE)) ||
((LIM_IS_IBSS_ROLE(session_entry) ||
- LIM_IS_AP_ROLE(session_entry) ||
- LIM_IS_BT_AMP_AP_ROLE(session_entry)) &&
+ LIM_IS_AP_ROLE(session_entry)) &&
(session_entry->limSmeState == eLIM_SME_NORMAL_STATE))) {
/* Trigger MLM_SETKEYS_REQ */
mlm_set_key_req = qdf_mem_malloc(sizeof(tLimMlmSetKeysReq));
@@ -3317,9 +3291,7 @@ lim_get_wpspbc_sessions_end:
static void __lim_counter_measures(tpAniSirGlobal pMac, tpPESession psessionEntry)
{
tSirMacAddr mac = { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF };
- if (LIM_IS_AP_ROLE(psessionEntry) ||
- LIM_IS_BT_AMP_AP_ROLE(psessionEntry) ||
- LIM_IS_BT_AMP_STA_ROLE(psessionEntry))
+ if (LIM_IS_AP_ROLE(psessionEntry))
lim_send_disassoc_mgmt_frame(pMac, eSIR_MAC_MIC_FAILURE_REASON,
mac, psessionEntry, false);
};
@@ -3429,8 +3401,7 @@ __lim_handle_sme_stop_bss_request(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
psessionEntry->transactionId = smetransactionId;
/* BTAMP_STA and STA_IN_IBSS should NOT send Disassoc frame */
- if (!LIM_IS_IBSS_ROLE(psessionEntry) &&
- !LIM_IS_BT_AMP_STA_ROLE(psessionEntry)) {
+ if (!LIM_IS_IBSS_ROLE(psessionEntry)) {
tSirMacAddr bcAddr = { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF };
if (stopBssReq.reasonCode == eSIR_SME_MIC_COUNTER_MEASURES)
/* Send disassoc all stations associated thru TKIP */
@@ -3577,8 +3548,7 @@ void __lim_process_sme_assoc_cnf_new(tpAniSirGlobal mac_ctx, uint32_t msg_type,
goto end;
}
- if ((!LIM_IS_AP_ROLE(session_entry) &&
- !LIM_IS_BT_AMP_AP_ROLE(session_entry)) ||
+ if ((!LIM_IS_AP_ROLE(session_entry)) ||
((session_entry->limSmeState != eLIM_SME_NORMAL_STATE) &&
(session_entry->limSmeState !=
eLIM_SME_NORMAL_CHANNEL_SCAN_STATE))) {
@@ -3731,8 +3701,7 @@ static void __lim_process_sme_addts_req(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
pSirAddts->req.tspec.tsinfo.traffic.userPrio);
)
- if (!LIM_IS_STA_ROLE(psessionEntry) &&
- !LIM_IS_BT_AMP_STA_ROLE(psessionEntry)) {
+ if (!LIM_IS_STA_ROLE(psessionEntry)) {
PELOGE(lim_log(pMac, LOGE, "AddTs received on AP - ignoring");)
lim_send_sme_addts_rsp(pMac, pSirAddts->rspReqd, eSIR_FAILURE,
psessionEntry, pSirAddts->req.tspec,
@@ -3977,8 +3946,7 @@ void lim_process_sme_addts_rsp_timeout(tpAniSirGlobal pMac, uint32_t param)
return;
}
- if (!LIM_IS_STA_ROLE(psessionEntry) &&
- !LIM_IS_BT_AMP_STA_ROLE(psessionEntry)) {
+ if (!LIM_IS_STA_ROLE(psessionEntry)) {
lim_log(pMac, LOGW, "AddtsRspTimeout in non-Sta role (%d)",
GET_LIM_SYSTEM_ROLE(psessionEntry));
pMac->lim.gLimAddtsSent = false;
diff --git a/core/mac/src/pe/sch/sch_beacon_gen.c b/core/mac/src/pe/sch/sch_beacon_gen.c
index d8339aa08e3c..3acbb7d18027 100644
--- a/core/mac/src/pe/sch/sch_beacon_gen.c
+++ b/core/mac/src/pe/sch/sch_beacon_gen.c
@@ -953,8 +953,6 @@ void sch_process_pre_beacon_ind(tpAniSirGlobal pMac, tpSirMsgQ limMsg)
switch (GET_LIM_SYSTEM_ROLE(psessionEntry)) {
case eLIM_STA_IN_IBSS_ROLE:
- case eLIM_BT_AMP_AP_ROLE:
- case eLIM_BT_AMP_STA_ROLE:
/* generate IBSS parameter set */
if (psessionEntry->statypeForBss == STA_ENTRY_SELF)
write_beacon_to_memory(pMac, (uint16_t) beaconSize,
diff --git a/core/sme/src/csr/csr_api_roam.c b/core/sme/src/csr/csr_api_roam.c
index 15c702f328c2..3950e624bdf2 100644
--- a/core/sme/src/csr/csr_api_roam.c
+++ b/core/sme/src/csr/csr_api_roam.c
@@ -13448,10 +13448,7 @@ QDF_STATUS csr_send_join_req_msg(tpAniSirGlobal pMac, uint32_t sessionId,
/* bsstype */
dwTmp = csr_translate_bsstype_to_mac_type
(pProfile->BSSType);
- /* Override BssType for BTAMP */
- if (dwTmp == eSIR_BTAMP_STA_MODE)
- dwTmp = eSIR_BTAMP_AP_MODE;
- csr_join_req->bsstype = dwTmp;
+ csr_join_req->bsstype = dwTmp;
/* dot11mode */
ucDot11Mode =
csr_translate_to_wni_cfg_dot11_mode(pMac,
diff --git a/core/wma/src/wma_data.c b/core/wma/src/wma_data.c
index 18bc5059501f..64fca4300424 100644
--- a/core/wma/src/wma_data.c
+++ b/core/wma/src/wma_data.c
@@ -1155,8 +1155,7 @@ void wma_set_linkstate(tp_wma_handle wma, tpLinkStateParams params)
params->status = true;
WMA_LOGD("%s: state %d selfmac %pM", __func__,
params->state, params->selfMacAddr);
- if ((params->state != eSIR_LINK_PREASSOC_STATE) &&
- (params->state != eSIR_LINK_DOWN_STATE)) {
+ if (params->state != eSIR_LINK_PREASSOC_STATE) {
WMA_LOGD("%s: unsupported link state %d",
__func__, params->state);
goto out;
diff --git a/core/mac/src/pe/sch/sch_beacon_process.c b/core/mac/src/pe/sch/sch_beacon_process.c
index 157ab11ca8da..7cf542cff880 100644
--- a/core/mac/src/pe/sch/sch_beacon_process.c
+++ b/core/mac/src/pe/sch/sch_beacon_process.c
@@ -338,7 +338,7 @@ tSirMacHTChannelWidth get_operating_channel_width(tpDphHashNode stads)
}
/*
* sch_bcn_process_sta_bt_amp_sta() - Process the received beacon frame for sta,
* bt_amp_sta
*
* @mac_ctx: mac_ctx
@@ -350,12 +350,12 @@ tSirMacHTChannelWidth get_operating_channel_width(tpDphHashNode stads)
* @sendProbeReq: out flag to indicate if probe rsp is to be sent
* @pMh: mac header
*
- * Process the received beacon frame for sta, bt_amp_sta
+ * Process the received beacon frame for sta
*
* Return: success of failure of operation
*/
static bool
-sch_bcn_process_sta_bt_amp_sta(tpAniSirGlobal mac_ctx,
+sch_bcn_process_sta(tpAniSirGlobal mac_ctx,
tpSchBeaconStruct bcn,
uint8_t *rx_pkt_info,
tpPESession session, uint8_t *bssIdx,
@@ -367,7 +367,6 @@ sch_bcn_process_sta_bt_amp_sta(tpAniSirGlobal mac_ctx,
/*
* This handles two cases:
* -- Infra STA receving beacons from AP
- * -- BTAMP_STA receving beacons from BTAMP_AP
*/
/* Always save the beacon into LIM's cached scan results */
lim_check_and_add_bss_description(mac_ctx, bcn, rx_pkt_info,
@@ -500,7 +499,7 @@ void update_nss(tpAniSirGlobal mac_ctx, tpDphHashNode sta_ds,
}
/*
* sch_bcn_process_sta_bt_amp_sta_ibss() - Process the received beacon frame
* for sta, bt_amp_sta and ibss
*
* @mac_ctx: mac_ctx
@@ -512,12 +511,12 @@ void update_nss(tpAniSirGlobal mac_ctx, tpDphHashNode sta_ds,
* @sendProbeReq: out flag to indicate if probe rsp is to be sent
* @pMh: mac header
*
- * Process the received beacon frame for sta, bt_amp_sta and ibss
+ * Process the received beacon frame for sta and ibss
*
* Return: void
*/
static void
-sch_bcn_process_sta_bt_amp_sta_ibss(tpAniSirGlobal mac_ctx,
+sch_bcn_process_sta_ibss(tpAniSirGlobal mac_ctx,
tpSchBeaconStruct bcn,
uint8_t *rx_pkt_info,
tpPESession session, uint8_t *bssIdx,
@@ -684,9 +683,7 @@ sch_bcn_process_sta_bt_amp_sta_ibss(tpAniSirGlobal mac_ctx,
* - call lim_handle_ibs_scoalescing with that session context.
* Infra STA receving beacons from AP to which it is connected
* - call sch_beacon_processFromAP with that session's context.
- * BTAMP STA receving beacons from BTAMP AP
* - call sch_beacon_processFromAP with that session's context.
- * BTAMP AP receiving beacons from BTAMP STA
* (here need to make sure BTAP creates session entry for BT STA)
* - just update the beacon count for heart beat purposes for now,
* for now, don't process the beacon.
@@ -726,9 +723,8 @@ static void __sch_beacon_process_for_session(tpAniSirGlobal mac_ctx,
if (LIM_IS_IBSS_ROLE(session)) {
lim_handle_ibss_coalescing(mac_ctx, bcn, rx_pkt_info, session);
- } else if (LIM_IS_STA_ROLE(session)
- || LIM_IS_BT_AMP_STA_ROLE(session)) {
- if (false == sch_bcn_process_sta_bt_amp_sta(mac_ctx, bcn,
+ } else if (LIM_IS_STA_ROLE(session)) {
+ if (false == sch_bcn_process_sta(mac_ctx, bcn,
rx_pkt_info, session, &bssIdx,
&beaconParams, &sendProbeReq, pMh))
return;
@@ -739,7 +735,6 @@ static void __sch_beacon_process_for_session(tpAniSirGlobal mac_ctx,
&bcn->HTInfo, bssIdx, session);
if (LIM_IS_STA_ROLE(session)
- || LIM_IS_BT_AMP_STA_ROLE(session)
|| LIM_IS_IBSS_ROLE(session)) {
/* Channel Switch information element updated */
if (bcn->channelSwitchPresent) {
@@ -758,9 +753,8 @@ static void __sch_beacon_process_for_session(tpAniSirGlobal mac_ctx,
}
}
if (LIM_IS_STA_ROLE(session)
- || LIM_IS_BT_AMP_STA_ROLE(session)
|| LIM_IS_IBSS_ROLE(session))
- sch_bcn_process_sta_bt_amp_sta_ibss(mac_ctx, bcn,
+ sch_bcn_process_sta_ibss(mac_ctx, bcn,
rx_pkt_info, session, &bssIdx,
&beaconParams, &sendProbeReq, pMh);
/* Obtain the Max Tx power for the current regulatory */
@@ -338,7 +338,7 @@ tSirMacHTChannelWidth get_operating_channel_width(tpDphHashNode stads)
}
/*
- * sch_bcn_process_sta_bt_amp_sta() - Process the received beacon frame for sta,
+ * sch_bcn_process_sta() - Process the received beacon frame for sta,
* bt_amp_sta
*
@@ -500,7 +499,7 @@ void update_nss(tpAniSirGlobal mac_ctx, tpDphHashNode sta_ds,
}
/*
- * sch_bcn_process_sta_bt_amp_sta_ibss() - Process the received beacon frame
+ * sch_bcn_process_sta_ibss() - Process the received beacon frame
* for sta, bt_amp_sta and ibss
*